==> App2App-0.0.5.tgz: package/src/android/App2App.java <==
package kr.itbox.app2app;

import org.apache.cordova.CordovaPlugin;
import org.apache.cordova.CallbackContext;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;



import android.net.Uri;
import android.app.AlertDialog;

import android.content.ActivityNotFoundException;
import android.content.Context;
import android.content.Intent;


import android.content.Intent;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;

import android.widget.Toast;

/**
 * This class echoes a string called from JavaScript.
 */
public class App2App extends CordovaPlugin {

    @Override
    public boolean execute(String action, JSONArray args, CallbackContext callbackContext) throws JSONException {
        if (action.equals("coolMethod")) {
            String message = args.getString(0);
            this.coolMethod(message, callbackContext);
            return true;
        }
        return false;
    }

    private void coolMethod(String message, CallbackContext callbackContext) {


        goUFO();

        if (message != null && message.length() > 0) {
            callbackContext.success(message);
        } else {
            callbackContext.error("Expected one non-empty string argument.");
        }
    }

    //UFO타운
    public void goUFO() {


        PackageManager pm = this.cordova.getActivity().getPackageManager();
        PackageInfo pi;
        String strAppPackage = "kr.danal.ufotown";
        try {

            pi = pm.getPackageInfo(strAppPackage,  PackageManager.GET_ACTIVITIES);

            //정상 스크립트 실행
            AlertDialog.Builder dialog = new AlertDialog.Builder(cordova.getActivity());
            dialog.setTitle("알림");
            dialog.setMessage("UFO 실행 성공");
            dialog.show();


//      실행시킬 패키지의 액티비를 알 경우,
//      ComponentName compName = new ComponentName("com.package","com.package.activity");
//      Intent intent = newIntent(Intent.ACTION_MAIN);
//      intent.addCategory(Intent.CATEGORY_LAUNCHER);
//      intent.setComponent(compName);
//      startActivity(intent);

//      실행시킬 패키지명만 알 경우,
//      Context context = this.cordova.getActivity(); //<- 이거 되는지 안되는지 체크해봐야함
            Intent intent = this.cordova.getActivity().getPackageManager().getLaunchIntentForPackage(strAppPackage);
            this.cordova.getActivity().startActivity(intent);



        }
        catch (PackageManager.NameNotFoundException e) {
            Toast.makeText(this.cordova.getActivity(), "UFO TOWN 앱이 설치되지 않았습니다.", Toast.LENGTH_SHORT).show();

            //스토어로 이동하기
            Intent intent = new Intent(Intent.ACTION_VIEW);
            intent.setData(Uri.parse("market://details?id=" + strAppPackage));
            this.cordova.getActivity().startActivity(intent);
        }


    }

}

==> App2App-0.0.7.tgz: package/src/android/App2App.java <==
package kr.itbox.app2app;

import org.apache.cordova.CordovaPlugin;
import org.apache.cordova.CallbackContext;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;



import android.net.Uri;
import android.app.AlertDialog;

import android.content.ActivityNotFoundException;
import android.content.Context;
import android.content.Intent;


import android.content.Intent;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;

import android.widget.Toast;

/**
 * This class echoes a string called from JavaScript.
 */
public class App2App extends CordovaPlugin {

    @Override
    public boolean execute(String action, JSONArray args, CallbackContext callbackContext) throws JSONException {
        if (action.equals("coolMethod")) {
            String message = args.getString(0);
            this.coolMethod(message, callbackContext);
            return true;
        }
        return false;
    }

    private void coolMethod(String message, CallbackContext callbackContext) {


        goUFO(message);

        if (message != null && message.length() > 0) {
            callbackContext.success(message);
        } else {
            callbackContext.error("Expected one non-empty string argument.");
        }
    }

    //UFO타운
    public void goUFO(String message) {


        PackageManager pm = this.cordova.getActivity().getPackageManager();
        PackageInfo pi;
        String strAppPackage = "kr.danal.ufotown";
        try {

            pi = pm.getPackageInfo(strAppPackage,  PackageManager.GET_ACTIVITIES);

//            //정상 스크립트 실행
//            AlertDialog.Builder dialog = new AlertDialog.Builder(cordova.getActivity());
//            dialog.setTitle("알림");
//            dialog.setMessage("UFO 실행 성공");
//            dialog.show();


//      실행시킬 패키지의 액티비를 알 경우,
//      ComponentName compName = new ComponentName("com.package","com.package.activity");
//      Intent intent = newIntent(Intent.ACTION_MAIN);
//      intent.addCategory(Intent.CATEGORY_LAUNCHER);
//      intent.setComponent(compName);
//      startActivity(intent);

//      실행시킬 패키지명만 알 경우,
//      Context context = this.cordova.getActivity(); //<- 이거 되는지 안되는지 체크해봐야함
            Intent intent = this.cordova.getActivity().getPackageManager().getLaunchIntentForPackage(strAppPackage);
            intent.putExtra("message", message);
            this.cordova.getActivity().startActivity(intent);



        }
        catch (PackageManager.NameNotFoundException e) {
            Toast.makeText(this.cordova.getActivity(), "UFO TOWN 앱이 설치되지 않았습니다.", Toast.LENGTH_SHORT).show();

            //스토어로 이동하기
            Intent intent = new Intent(Intent.ACTION_VIEW);
            intent.setData(Uri.parse("market://details?id=" + strAppPackage));
            this.cordova.getActivity().startActivity(intent);
        }


    }

}
